# eclipsetorch

[![PyPI version](https://badge.fury.io/py/eclipsetorch.svg)](https://badge.fury.io/py/eclipsetorch)

**eclipsetorch** is a tool kit that provides functions that make making models a bit easier for pytorch. 
The main focus was originally to make models without having to do too much mental math to figure out of the shape of the tensors that flow through the model are correct

## Features

- **Stack Functions**: These are functions that output multiple layers that can be placed in a sequential or use on their own
                        - conv and unconv are examples of this

## Examples

```python

```